@@ -168,6 +168,7 @@ class Checker(object, metaclass=abc.ABCMeta):
             raise
         finally:
             if broken_encoding:
+                # pylint: disable=no-member
                 s = broken_encoding.object
                 assert isinstance(s, bytes)
                 begin = max(broken_encoding.start - 40, 0)
@@ -178,6 +179,7 @@ class Checker(object, metaclass=abc.ABCMeta):
                     tags.safestr('cannot be decoded as'),
                     broken_encoding.encoding.upper(),
                 )
+                # pylint: enable=no-member
                 broken_encoding = True
         ctx = misc.Namespace()
         ctx.file = file
@@ -643,6 +645,7 @@ class Checker(object, metaclass=abc.ABCMeta):
             self.tag('no-report-msgid-bugs-to-header-field')
         for report_msgid_bugs_to in report_msgid_bugs_tos:
             real_name, email_address = email.utils.parseaddr(report_msgid_bugs_to)
+            del real_name
             if '@' not in email_address:
                 uri = urllib.parse.urlparse(report_msgid_bugs_to)
                 if uri.scheme == '':
@@ -666,6 +669,7 @@ class Checker(object, metaclass=abc.ABCMeta):
         translator_emails = {}
         for translator in translators:
             translator_name, translator_email = email.utils.parseaddr(translator)
+            del translator_name
             translator_emails[translator_email] = translator
             if '@' not in translator_email:
                 self.tag('invalid-last-translator', translator)
@@ -685,8 +689,9 @@ class Checker(object, metaclass=abc.ABCMeta):
             self.tag('no-language-team-header-field')
         for team in teams:
             team_name, team_email = email.utils.parseaddr(team)
+            del team_name
             if '@' not in team_email:
-                # TODO: An URL is also allowed here.
+                # TODO: A URL is also allowed here.
                 # self.tag('invalid-language-team', translator)
                 pass
             elif domains.is_email_in_special_domain(team_email):
