@@ -35,11 +35,11 @@ import tempfile
 from lib import check
 from lib import ling
 from lib import misc
-from lib import paths
+from lib import paths as pathmod
 from lib import tags
 from lib import terminal
 
-__version__ = '0.25.1'
+__version__ = '0.25.2'
 
 def initialize_terminal():
     if sys.stdout.isatty():
@@ -49,6 +49,7 @@ def initialize_terminal():
     sys.stdout = io.TextIOWrapper(sys.stdout.buffer,
         encoding=sys.stdout.encoding,
         errors='backslashreplace',
+        line_buffering=sys.stdout.line_buffering,
     )
 
 class Checker(check.Checker):
@@ -102,6 +103,7 @@ def check_deb(filename, *, options):
             fake_root=(real_root, os.path.join(filename, ''))
         )
         for root, dirs, files in os.walk(tmpdir):
+            del dirs
             for path in files:
                 path = os.path.join(root, path)
                 if os.path.islink(path):
@@ -152,10 +154,43 @@ def parse_jobs(s):
     return n
 parse_jobs.__name__ = 'jobs'
 
+class VersionAction(argparse.Action):
+
+    def __init__(self, option_strings, dest=argparse.SUPPRESS):
+        super(VersionAction, self).__init__(
+            option_strings=option_strings,
+            dest=dest,
+            nargs=0,
+            help="show program's version information and exit"
+        )
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        print('{prog} {0}'.format(__version__, prog=parser.prog))
+        print('+ Python {0}.{1}.{2}'.format(*sys.version_info))
+        print('+ polib {0}'.format(check.polib.__version__))
+        rply = check.gettext.intexpr.rply
+        try:
+            rply_version = rply.__version__
+        except AttributeError:
+            # __version__ is available only since rply 0.7.4+:
+            # https://github.com/alex/rply/pull/58
+            try:
+                import pkg_resources
+                [dist, *rest] = pkg_resources.require('rply')
+                del rest
+                assert dist.project_name == 'rply'
+                rply_version = dist.version
+            except ImportError:
+                # oh well...
+                rply_version = None
+        if rply_version is not None:
+            print('+ rply {0}'.format(rply_version))
+        parser.exit()
+
 def main():
     initialize_terminal()
     ap = argparse.ArgumentParser(description=__doc__)
-    ap.add_argument('--version', action='version', version='%(prog)s {}'.format(__version__))
+    ap.add_argument('--version', action=VersionAction)
     ap.add_argument('-l', '--language', metavar='<lang>', help='assume this language')
     ap.add_argument('--unpack-deb', action='store_true', help='allow unpacking Debian packages')
     ap.add_argument('-j', '--jobs', type=parse_jobs, metavar='<n>', default=None, help='use <n> processes')
@@ -166,7 +201,7 @@ def main():
     options = ap.parse_args()
     files = options.files
     del options.files
-    paths.check()
+    pathmod.check()
     if options.language is not None:
         try:
             language = ling.parse_language(options.language)
