@@ -29,10 +29,12 @@ class _dummy_curses:
 
     @staticmethod
     def tigetstr(*args, **kwargs):
+        del args, kwargs
         return b''
 
     @staticmethod
     def tparm(*args, **kwargs):
+        del args, kwargs
         return b''
 
 _curses = _dummy_curses
@@ -73,9 +75,9 @@ def initialize():
     '''
     initialize the terminal
     '''
-    global _curses
+    global _curses  # pylint: disable=global-statement
     try:
-        import curses as _curses
+        import curses as _curses  # pylint: disable=redefined-outer-name
     except ImportError:
         return
     try:
